@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw/Class::Accessor::Fast/;
 use 5.00800;
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 use Carp ();
 use Scalar::Util ();
 use UNIVERSAL::require;
@@ -46,13 +46,13 @@ sub _load_session {
             } else {
                 # session was expired? or session fixation?
                 # regen session id.
-                $self->session_id( $self->_generate_session_id($self->request) );
+                $self->session_id( $self->_generate_session_id() );
                 $self->is_fresh(1);
             }
         }
     } else {
         # no sid; generate it
-        $self->session_id( $self->_generate_session_id($self->request) );
+        $self->session_id( $self->_generate_session_id() );
         $self->is_fresh(1);
     }
 }
@@ -65,7 +65,7 @@ sub _generate_session_id {
 
 sub response_filter {
     my ($self, $response) = @_;
-    Carp::croak "missing response" unless Scalar::Util::blessed $response;
+    Carp::croak "missing response" unless ref $response;
 
     $self->state->response_filter($self->session_id, $response);
 }
@@ -199,12 +199,23 @@ HTTP::Session - simple session
 
 Yet another session manager.
 
-easy to integrate with L<HTTP::Engine> =)
+easy to integrate with L<PSGI> =)
 
 =head1 METHODS
 
 =over 4
 
+=item my $session = HTTP::Session->new(store => $store, state => $state, request => $req)
+
+This method creates new instance of HTTP::Session.
+
+C<store> is instance of HTTP::Session::Store::*.
+
+C<state> is instance of HTTP::Session::State::*.
+
+C<request> is duck typed object.C<request> object should have C<header>, C<address>, C<param>.
+You can use PSGI's $env instead.
+
 =item $session->load_session()
 
 load session
@@ -225,6 +236,8 @@ filtering header
 
 filtering response. this method runs html_filter, redirect_filter and header_filter.
 
+$res should be PSGI's response array, instance of L<HTTP::Response>, or L<HTTP::Engine::Response>.
+
 =item $session->keys()
 
 keys of session.
